import React, { FC, Fragment, useEffect, useState } from "react";
import ProductCheckout from "./components/ProductCheckout";
import SolanaNetwork from "./components/SolanaNetwork";
import WalletConnectModal from "./components/WalletConnectModal";
import WalletContext from "./components/WalletContext";
import { WalletAdapterNetwork } from "@solana/wallet-adapter-base";
// import LoadingDots from "../components/Loading/LoadingDots";
import {
  useMakePaymentMutation,
  useValidatePaymentLinkQuery,
} from "../services/checkout-service";

import { useAppDispatch } from "../app/hooks";
import { transactionResult } from "../features/checkoutReducer";
import { isFetchBaseQueryError, isErrorWithMessage } from "../components/types";
import WalletOptionModal from "../components/Model/WalletOptionModal";
import SuccessModal from "../components/Model/SuccessModal";
import { notification, Button } from "antd";

const Checkout: FC = () => {

  const [selectedWallet, setSelectedWallet] = useState<
    "solana" | "wallet-connect" | "checkout" | "success"
  >("checkout");
  const [data, setData] = useState<any>();
  const [showCheckout, setShowCheckout] = useState<boolean>(false);

  const [showSuccess, setShowSuccess] = useState<boolean>(false);
  const [showWalletConnet, setShowWalletConnect] = useState<boolean>(false);
  const [showWalletOption, setShowWalletOption] = useState<boolean>(false);
  const [paymentLoading, setPaymentLoading] = useState<boolean>(false);
  const [initiateTransaction] = useMakePaymentMutation();
  const [transactionValue, setTransactionValue] = useState();
  const dispatch = useAppDispatch();
  let environment = "TEST";
  //TODO fetch environment and store whether in state or whatever
  // let environment = data?.data.environment;

  async function sendPayment(
    option: "solana" | "wallet-connect" | "success",
    retry = false
  ) {
    setPaymentLoading(true);
    setShowWalletOption(false);
    setShowSuccess(true);
    // if (retry) setLoading(true);
    try {
      let res = await initiateTransaction({
        data: transactionValue,
      }).unwrap();
      console.log("res>>", res);
      dispatch(transactionResult(res.data));
      setSelectedWallet(option);
      if (option === "wallet-connect") setShowWalletConnect(true);
    } catch (err) {
      console.log(err);
      if (isFetchBaseQueryError(err)) {
        const errMsg =
          //@ts-ignore
          "error" in err ? err.error : JSON.stringify(err.data?.message);
        notification.error({
          message: errMsg,
        });
      } else if (isErrorWithMessage(err)) {
        console.log(err);
      }
    }
    setPaymentLoading(false);
    setShowSuccess(false);
  }

  useEffect(() => {}, []);
  const showCheckoutHandler = () => {
    setShowCheckout(true);
  };
  console.log("Data>>", selectedWallet);

  return (
    <Fragment>
      <WalletContext
        network={
          environment === "LIVE"
            ? WalletAdapterNetwork.Mainnet
            : WalletAdapterNetwork.Devnet
        }
      >
        {showCheckout === false ? (
          <div className="flex justify-center pt-6" onClick={showCheckoutHandler}>
            <Button type="primary" size="large">
              Fund With Crypto
            </Button>
          </div>
        ) : null}
        {selectedWallet === "checkout" && showCheckout === true ? (
          <ProductCheckout
            // data={data.data}
            setData={setData}
            // loading={paymentLoading}
            setShowWalletOption={setShowWalletOption}
            setTransactionValue={setTransactionValue}
          />
        ) : selectedWallet === "solana" ? (
          <SolanaNetwork
            setSelectedWallet={setSelectedWallet}
            makePayment={sendPayment}
            redirect=""
            successMessage="successMessage"
          />
        ) : selectedWallet === "wallet-connect" ? (
          <WalletConnectModal
            setShowSuccess={setShowSuccess}
            setSelectedWallet={setSelectedWallet}
            show={showWalletConnet}
            onCancel={() => {
              setShowWalletConnect(false);
              setSelectedWallet("checkout");
            }}
            // data={transactionValue}
            title="Pay with Crypto Wallet"
          />
        ) : selectedWallet === "success" ? (
          <SuccessModal
            show={showSuccess}
            onCancel={() => {
              setShowSuccess(false);
              setSelectedWallet("checkout");
            }}
            // title="Success"
          />
        ) : null}

        {showWalletOption && (
          <WalletOptionModal
            show={showWalletOption}
            onCancel={() => setShowWalletOption(false)}
            sendPayment={sendPayment}
            title="Pay with"
          />
        )}
      </WalletContext>
    </Fragment>
  );
};
export default Checkout;
