// Need to use the React-specific entry point to import createApi
import { createApi, fetchBaseQuery } from "@reduxjs/toolkit/query/react";
import {
  ValidatedPaymentLink,
  IPropsSupportedCurrency,
} from "../components/types";

// Define a service using a base URL and expected endpoints
export const checkoutApi = createApi({
  reducerPath: "checkoutApi",
  baseQuery: fetchBaseQuery({ baseUrl: `${process.env.REACT_APP_IVORY_API}/` }),
  tagTypes: ["IPropsSupportedCurrency"],
  endpoints: (builder) => ({
    validatePaymentLink: builder.query<ValidatedPaymentLink, string>({
      query: (reference) => `payment-links/${reference}/pay`,
    }),
    makePayment: builder.mutation<any, any>({
      query({ data }) {
        return {
          url: `/transactions`,
          headers: {
            Authorization:
              "pk_qxKGmPXURHPGiN7J0x0NxfuYoaJ45r5eRGbVqLkyxLd4vcdwmRvnfyqbsKOpFg4a",
          },
          method: "POST",
          body: data,
        };
      },
    }),
    payWithWalletConnect: builder.mutation<any, any>({
      query({ data, ref }) {
        return {
          url: `transactions/${ref}/wallet-connect`,
          method: "POST",
          body: data,
        };
      },
    }),
    paymentListener: builder.query<any, string>({
      query: (reference) => `transactions/${reference}/verify`,
    }),
    walletListener: builder.mutation<any, string>({
      query: (reference) => `transactions/${reference}/verify`,
      transformResponse: (response: { data: any }, meta, arg) => response.data,
    }),
    requestRefund: builder.query<any, string>({
      query: (reference) => `refunds/${reference}`,
    }),
    refundWallet: builder.mutation<any, any>({
      query({ data, ref }) {
        return {
          url: `refunds/${ref}/transfer`,
          method: "POST",
          body: data,
        };
      },
    }),
    getCurrency: builder.query<Array<IPropsSupportedCurrency>, string>({
      query: (id) => `businesses/${id}/supported-cryptocurrencies`,
      transformResponse: (
        response: { data: Array<IPropsSupportedCurrency> },
        meta,
        arg
      ) => response.data,
    }),
  }),
});

export const {
  useValidatePaymentLinkQuery,
  useMakePaymentMutation,
  usePayWithWalletConnectMutation,
  usePaymentListenerQuery,
  useRequestRefundQuery,
  useRefundWalletMutation,
  useWalletListenerMutation,
  useGetCurrencyQuery,
} = checkoutApi;
